==> amarok-2.4.0.tar.bz2: amarok-2.4.0/src/scriptengine/AmarokScriptConfig.cpp <==
/****************************************************************************************
 * Copyright (c) 2008 Peter ZHOU <peterzhoulei@gmail.com>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "AmarokScriptConfig.h"

#include "App.h"

#include <KConfigGroup>
#include <KGlobal>

namespace AmarokScript
{
    AmarokScriptConfig::AmarokScriptConfig( const QString& name )
        : QObject( kapp )
        , m_name( name )
    {}

    AmarokScriptConfig::~AmarokScriptConfig()
    {}

    QVariant AmarokScriptConfig::readConfig( QString name, QVariant defaultValue ) const
    {
        return KGlobal::config()->group( m_name ).readEntry( name, defaultValue );
    }

    QString AmarokScriptConfig::readConfig( QString name, QString defaultValue ) const
    {
        return KGlobal::config()->group( m_name ).readEntry( name, defaultValue );
    }

    void AmarokScriptConfig::writeConfig( QString name, QVariant content )
    {
        KGlobal::config()->group( m_name ).writeEntry( name, content );
    }

    void AmarokScriptConfig::writeConfig( QString name, QString content )
    {
        KGlobal::config()->group( m_name ).writeEntry( name, content );
    }
}

#include "AmarokScriptConfig.moc"

==> amarok-2.5.0.tar.bz2: amarok-2.5.0/src/scriptengine/AmarokScriptConfig.cpp <==
/****************************************************************************************
 * Copyright (c) 2008 Peter ZHOU <peterzhoulei@gmail.com>                               *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "AmarokScriptConfig.h"

#include <KConfigGroup>
#include <KSharedConfig>
#include <KGlobal>

#include <QScriptEngine>

namespace AmarokScript
{
    AmarokScriptConfig::AmarokScriptConfig( const QString& name, QScriptEngine *engine )
        : QObject( engine )
        , m_name( name )
    {
        QScriptValue scriptObject = engine->newQObject( this, QScriptEngine::AutoOwnership );
        engine->globalObject().property( "Amarok" ).setProperty( "Script", scriptObject );
    }

    AmarokScriptConfig::~AmarokScriptConfig()
    {}

    QVariant AmarokScriptConfig::readConfig( const QString &name, const QVariant &defaultValue ) const
    {
        return KGlobal::config()->group( m_name ).readEntry( name, defaultValue );
    }

    QString AmarokScriptConfig::readConfig( const QString &name, const QString &defaultValue ) const
    {
        return KGlobal::config()->group( m_name ).readEntry( name, defaultValue );
    }

    void AmarokScriptConfig::writeConfig( const QString &name, const QVariant &content )
    {
        KGlobal::config()->group( m_name ).writeEntry( name, content );
    }

    void AmarokScriptConfig::writeConfig( const QString &name, const QString &content )
    {
        KGlobal::config()->group( m_name ).writeEntry( name, content );
    }
}

#include "AmarokScriptConfig.moc"
